==> ubuntu-sso-client_3.0.2.orig.tar.gz: ubuntu-sso-client-3.0.2/ubuntu_sso/main/tests/__init__.py <==
# -*- coding: utf-8 -*-
# Author: Manuel de la Pena <manuel@canonical.com>
#
# Copyright 2011-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""Test the different main implementations."""

import sys

from twisted.internet import defer

from ubuntu_sso.tests import TOKEN

# Invalid name "BaseTestCase"
# pylint: disable=C0103

if sys.platform == 'win32':
    from ubuntu_sso.utils.tests.test_ipc import BaseIPCTestCase
    BaseTestCase = BaseIPCTestCase
else:
    from ubuntuone.devtools.testcases.dbus import DBusTestCase
    BaseTestCase = DBusTestCase

# pylint: enable=C0103


class FakedCredentials(object):
    """A very dummy Credentials object."""

    def find_credentials(self, *a, **kw):
        """Retrieve credentials."""
        return defer.succeed(TOKEN)

    def clear_credentials(self, *a, **kw):
        """Clear credentials."""
        return defer.succeed(None)

    def store_credentials(self, *a, **kw):
        """Store credentials."""
        return defer.succeed(None)

    def register(self, *a, **kw):
        """Register."""
        return defer.succeed(TOKEN)

    def login(self, *a, **kw):
        """Login."""
        return defer.succeed(TOKEN)

==> ubuntu-sso-client_13.10.orig.tar.gz: ubuntu-sso-client-13.10/ubuntu_sso/main/tests/__init__.py <==
# -*- coding: utf-8 -*-
# Author: Manuel de la Pena <manuel@canonical.com>
#
# Copyright 2011-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
"""Test the different main implementations."""

import sys

from twisted.internet import defer

from ubuntu_sso.tests import TOKEN

# Invalid name "BaseTestCase"
# pylint: disable=C0103

if sys.platform == 'win32':
    from ubuntu_sso.main.tests import windows
    BaseTestCase = windows.BaseTestCase
else:
    from ubuntu_sso.main.tests import linux
    BaseTestCase = linux.BaseTestCase

# pylint: enable=C0103


class FakedCredentials(object):
    """A very dummy Credentials object."""

    def find_credentials(self, *a, **kw):
        """Retrieve credentials."""
        return defer.succeed(TOKEN)

    def clear_credentials(self, *a, **kw):
        """Clear credentials."""
        return defer.succeed(None)

    def store_credentials(self, *a, **kw):
        """Store credentials."""
        return defer.succeed(None)

    def register(self, *a, **kw):
        """Register."""
        return defer.succeed(TOKEN)

    def login(self, *a, **kw):
        """Login."""
        return defer.succeed(TOKEN)
